# @aws-sdk/client-dynamodb-browser

[![NPM version](https://img.shields.io/npm/v/@aws-sdk/client-dynamodb-browser/preview.svg)](https://www.npmjs.com/package/@aws-sdk/client-dynamodb-browser)
[![NPM downloads](https://img.shields.io/npm/dm/@aws-sdk/client-dynamodb-browser.svg)](https://www.npmjs.com/package/@aws-sdk/client-dynamodb-browser)

## Description

<fullname>Amazon DynamoDB</fullname> <p>Amazon DynamoDB is a fully managed NoSQL database service that provides fast and predictable performance with seamless scalability. DynamoDB lets you offload the administrative burdens of operating and scaling a distributed database, so that you don't have to worry about hardware provisioning, setup and configuration, replication, software patching, or cluster scaling.</p> <p>With DynamoDB, you can create database tables that can store and retrieve any amount of data, and serve any level of request traffic. You can scale up or scale down your tables' throughput capacity without downtime or performance degradation, and use the AWS Management Console to monitor resource utilization and performance metrics.</p> <p>DynamoDB automatically spreads the data and traffic for your tables over a sufficient number of servers to handle your throughput and storage requirements, while maintaining consistent and fast performance. All of your data is stored on solid state disks (SSDs) and automatically replicated across multiple Availability Zones in an AWS region, providing built-in high availability and data durability. </p>

## Installing

To install the this package using NPM, simply type the following into a terminal window:

```
npm install @aws-sdk/client-dynamodb-browser
```

## Getting Started

### Import

The AWS SDK is modulized by clients and commands in CommonJS modules. To send a request, you only need to import the client(`DynamoDBClient`) and the commands you need, for example `BatchGetItemCommand`:

```javascript
//JavaScript
const {
  DynamoDBClient
} = require("@aws-sdk/client-dynamodb-browser/DynamoDBClient");
const {
  BatchGetItemCommand
} = require("@aws-sdk/client-dynamodb-browser/commands/BatchGetItemCommand");
```

```javascript
//TypeScript
import { DynamoDBClient } from "@aws-sdk/client-dynamodb-browser/DynamoDBClient";
import { BatchGetItemCommand } from "@aws-sdk/client-dynamodb-browser/commands/BatchGetItemCommand";
```

### Usage

To send a request, you:

- Initiate client with configuration (e.g. credentials, region). For more information you can refer to the [API reference][].
- Initiate command with input parameters.
- Call `send` operation on client with command object as input.
- If you are using a custom http handler, you may call `destroy()` to close open connections.

```javascript
const dynamoDB = new DynamoDBClient({ region: "region" });
//clients can be shared by different commands
const params = {
  RequestItems: {
    /**a map with key of string and value of structure*/
  }
};
const batchGetItemCommand = new BatchGetItemCommand(params);
dynamoDB
  .send(batchGetItemCommand)
  .then(data => {
    // do something
  })
  .catch(error => {
    // error handling
  });
```

In addition to using promises, there are 2 other ways to send a request:

```javascript
// async/await
try {
  const data = await dynamoDB.send(batchGetItemCommand);
  // do something
} catch (error) {
  // error handling
}
```

```javascript
// callback
dynamoDB.send(batchGetItemCommand, (err, data) => {
  //do something
});
```

The SDK can also send requests using the simplified callback style from version 2 of the SDK.

```javascript
import * as AWS from "@aws-sdk/@aws-sdk/client-dynamodb-browser/DynamoDB";
const dynamoDB = new AWS.DynamoDB({ region: "region" });
dynamoDB.batchGetItem(params, (err, data) => {
  //do something
});
```

### Troubleshooting

When the service returns an exception, the error will include the exception information, as well as response metadata (e.g. request id).

```javascript
try {
  const data = await dynamoDB.send(batchGetItemCommand);
  // do something
} catch (error) {
  const metadata = error.$metadata;
  console.log(
    `requestId: ${metadata.requestId}
cfId: ${metadata.cfId}
extendedRequestId: ${metadata.extendedRequestId}`
  );
  /*
The keys within exceptions are also parsed. You can access them by specifying exception names:
    if(error.name === 'SomeServiceException') {
        const value = error.specialKeyInException;
    }
*/
}
```

## Getting Help

Please use these community resources for getting help. We use the GitHub issues for tracking bugs and feature requests and have limited bandwidth to address them.

- Ask a question on [StackOverflow](https://stackoverflow.com/questions/tagged/aws-sdk-js) and tag it with `aws-sdk-js`
- Come join the AWS JavaScript community on [gitter](https://gitter.im/aws/aws-sdk-js-v3)
- If it turns out that you may have found a bug, please [open an issue](https://github.com/aws/aws-sdk-js-v3/issues)

## Contributing

This client code is generated automatically. Any modifications will be overwritten the next time the `@aws-sdk/@aws-sdk/client-dynamodb-browser' package is updated. To contribute to SDK you can checkout our [code generator package][].

## License

This SDK is distributed under the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0),
see LICENSE for more information.

[code generator package]: https://github.com/aws/aws-sdk-js-v3/tree/master/packages/service-types-generator
[api reference]: https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/
